pub struct Calculator { /* private fields */ }Implementations
Sourceimpl Calculator
impl Calculator
pub fn new() -> Self
Sourcepub fn pop(&mut self, sample: u32, unique: u32) -> Result<u32, PopProbError>
pub fn pop(&mut self, sample: u32, unique: u32) -> Result<u32, PopProbError>
Calculates the most likely population size if sample elements are selected randomly
with replacement from the population and unique of these elements are unique.
Sourcepub fn prob_pop(
&mut self,
sample: u32,
unique: u32,
size: u32,
) -> Result<f64, PopProbError>
pub fn prob_pop( &mut self, sample: u32, unique: u32, size: u32, ) -> Result<f64, PopProbError>
Calculates the probability that a population contains exactly size unique elements if
sample elements are selected randomly with replacement from the population and
unique of these elements are unique.